# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

Name:           python3-pynest2d
Version:        4.12.1
Release:        1%{?dist}
Summary:        Python bindings for libnest2d
License:        LGPLv3
URL:            https://github.com/Ultimaker/pynest2d
Source:         %{url}/archive/%{version}/pynest2d-%{version}.tar.gz
# Downstream patch: add PyQt5 namespace
Patch0:         pynest2d-4.12.1-PyQt5.sip.patch
# Retrieve required flags from Libnest2D target
# https://github.com/Ultimaker/pynest2d/pull/3
Patch1:         pynest2d-4.12.1-flags.patch
Patch2:		pynest2d-4.8.0-boost169.patch
Patch3:		pynest2d-4.8.0-NLopt.patch
BuildRequires:  cmake3
%if 0%{?rhel} < 8
BuildRequires:  devtoolset-11-gcc-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  libnest2d-static
BuildRequires:  python3-devel
BuildRequires:  python36-sip-devel < 5
BuildRequires:  python36-pyqt5-sip
Requires:       python36-pyqt5-sip

%description
Binding allowing libnest2d to be called from Python using NumPy.

Summary:        %{summary}

%description -n python3-pynest2d
Binding allowing libnest2d to be called from Python using NumPy.


%prep
%autosetup -n pynest2d-%{version} -p1

# Boost 1.75+ needs C++14, upstream: https://github.com/Ultimaker/pynest2d/pull/7
sed -i 's/CMAKE_CXX_STANDARD 11/CMAKE_CXX_STANDARD 14/' CMakeLists.txt


%build
%if 0%{?rhel} < 8
# Run with devtoolset-11
if [[ $X_SCLS != *devtoolset-11* ]]; then
    /usr/bin/scl enable devtoolset-11 "bash -e $(printf '%q' "$0")"
    exit
fi
%endif
%cmake3
%cmake3_build


%install
%if 0%{?rhel} < 8
# Run with devtoolset-11
if [[ $X_SCLS != *devtoolset-11* ]]; then
    /usr/bin/scl enable devtoolset-11 "bash -e $(printf '%q' "$0")"
    exit
fi
%endif
%cmake3_install


%files -n python3-pynest2d
%license LICENSE
%doc README.md
%{python3_sitearch}/pynest2d.so


%changelog
* Thu Jan 06 2022 Peter Ajamian <pj@ghettoforge.org> - 4.12.1-1
- 4.12.1

* Wed Jan 05 2022 Peter Ajamian <pj@ghettoforge.org> - 4.8.0-6
- Rebuild for EL7

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 4.8.0-4
- Rebuilt for Python 3.10

* Tue Mar 30 2021 Jonathan Wakely <jwakely@redhat.com> - 4.8.0-3
- Rebuilt for removed libstdc++ symbol (#1937698)

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Mon Dec 28 2020 Miro Hrončok <mhroncok@redhat.com> - 4.8.0-1
- Initial package adapted from SUSE (by Stefan Brüns <stefan.bruens@rwth-aachen.de>)
